define(
//begin v1.x content
({
	"findLabel": "Najdi:",
	"findTooltip": "Vnesite besedilo za iskanje",
	"replaceLabel": "Zamenjaj z: ",
	"replaceTooltip": "Vnesite besedilo za zamenjavo ",
	"findReplace": "Najdi in zamenjaj",
	"matchCase": "Razlikuj velike in male črke",
	"matchCaseTooltip": "Razlikuj velike in male črke",
	"backwards": "Nazaj",
	"backwardsTooltip": "Vzvratno iskanje besedila ",
	"replaceAllButton": "Zamenjaj vse",
	"replaceAllButtonTooltip": "Zamenjaj celotno besedilo ",
	"findButton": "Najdi",
	"findButtonTooltip": "Najdi besedilo ",
	"replaceButton": "Zamenjaj ",
	"replaceButtonTooltip": "Zamenjaj besedilo ",
	"replaceDialogText": "Zamenjanih ${0} pojavitev. ",
	"eofDialogText": "Zadnja pojavitev ${0}",
	"eofDialogTextFind": "najdeno ",
	"eofDialogTextReplace": "zamenjano "
})

//end v1.x content
);
